@@ -9,6 +9,7 @@ our $VERSION = q{2.00_27};
 
 use SOAP::WSDL::Generator::Visitor::Typemap;
 use SOAP::WSDL::Generator::Visitor::Typelib;
+use SOAP::WSDL::Generator::Template::Plugin::XSD;
 use base qw(SOAP::WSDL::Generator::Template);
 
 my %output_of  :ATTR(:name<output> :default<()>);
@@ -144,7 +145,21 @@ sub generate_typemap {
             'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
             'Fault/detail' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
             %{ $typemap_of{ident $self }},
-        }
+        },
+        resolver => SOAP::WSDL::Generator::Template::Plugin::XSD->new({
+            namespace_prefix_map => {
+                'http://www.w3.org/2001/XMLSchema' => 'SOAP::WSDL::XSD::Typelib::Builtin',
+            },
+            namespace_map => {
+            },
+            prefix => {
+                interface => $self->get_interface_prefix,
+                element => $self->get_element_prefix,
+                server => $self->get_server_prefix,
+                type => $self->get_type_prefix,
+                typemap => $self->get_typemap_prefix,
+            }
+        }),
     });
     for my $service (@{ $self->get_definitions->get_service }) {
             $visitor->visit_Service( $service );
