@@ -9,13 +9,11 @@ our $VERSION = q{2.00_25};
 
 my %path_of             :ATTR(:name<path>           :default<[]>);
 my %typemap_of          :ATTR(:name<typemap>        :default<()>);
-my %type_prefix_of      :ATTR(:name<type_prefix>    :default<()>);
-my %element_prefix_of   :ATTR(:name<element_prefix> :default<()>);
+my %resolver_of         :ATTR(:name<resolver>       :default<()>);
 
 sub START {
     my ($self, $ident, $arg_ref) = @_;
-    $type_prefix_of{ $ident } ||= 'MyTypes';
-    $element_prefix_of{ $ident } ||= 'MyElements';
+    $resolver_of { $ident } = $arg_ref->{ resolver };
 }
 
 sub set_typemap_entry {
@@ -149,18 +147,13 @@ sub process_referenced_type {
     # Caveat: visits type if it's a referenced type from the
     # a ? b : c operation.
     my ($type, $typeclass);
-    if ( $ns eq 'http://www.w3.org/2001/XMLSchema' ) {
-        $typeclass = "SOAP::WSDL::XSD::Typelib::Builtin::$localname";
-    }
-    else {
-        $type = $self->get_definitions()->first_types()->find_type( $ns, $localname );
-        $typeclass = join( q{::}, $type_prefix_of{$ident}, $type->get_name() );
-    }
+    $type = $self->get_definitions()->first_types()->find_type( $ns, $localname );
+    $typeclass = join( q{::}, $self->get_resolver()->get_type_prefix($ns), $localname );
 
     # set before to allow it to be used from inside _accept
     $self->set_typemap_entry($typeclass);
 
-    $type->_accept($self) if ($type);
+    $type->_accept($self) if ($ns ne 'http://www.w3.org/2001/XMLSchema');
 
     # set afterwards again (just to be sure...)
     $self->set_typemap_entry($typeclass);
@@ -203,14 +196,16 @@ sub visit_XSD_Element {
             # warn "simpleType " . $element->get_name();
             my @path = @{ $path_of{ ${ $self } } };
             my $typeclass = defined ($parent)
-                ? join '::_', $parent , $element->get_name()
-                : join q{::}, $element_prefix_of{$ident}, $element->get_name();
+                ? join q{::_}, $parent , $element->get_name()
+                : join q{::}, $self->resolver()->get_element_prefix( $element->get_targetNamespace), $element->get_name();
             $self->set_typemap_entry($typeclass);
+            $typeclass =~s{\.}{::}g;
+            $typeclass =~s{\-}{_}g;
             last SWITCH;
         }
 
         # for atomic and complex types , and ref elements
-        my $typeclass = join q{::}, $element_prefix_of{$ident}, $element->get_name();
+        my $typeclass = join q{::}, $self->get_resolver()->get_element_prefix( $element->get_targetNamespace), $element->get_name();
         $typeclass =~s{\.}{::}g;
         $typeclass =~s{\-}{_}g;
         $self->set_typemap_entry($typeclass);
@@ -226,7 +221,7 @@ sub visit_XSD_Element {
     # a normal (not atomic) type, we just override it here
     if (not defined($parent)) {
         # for atomic and complex types , and ref elements
-        my $typeclass = join q{::}, $element_prefix_of{$ident}, $element->get_name();
+        my $typeclass = join q{::}, $self->get_resolver()->get_element_prefix($element->get_targetNamespace), $element->get_name();
         $typeclass =~s{\.}{::}g;
         $typeclass =~s{\-}{_}g;
         $self->set_typemap_entry($typeclass);
@@ -238,11 +233,11 @@ sub visit_XSD_Element {
 
 sub visit_XSD_ComplexType {
     my ($self, $ident, $type) = ($_[0], ident $_[0], $_[1] );
-    my $content_model = $type->get_flavor();
-    # TODO is this allowed ? or should we better die ?
-    return if not $content_model; # empty complexType
+    my $variety = $type->get_variety();
 
-    if ( grep { $_ eq $content_model} qw(all sequence choice) )
+    return if not $variety; # empty complexType
+
+    if ( grep { $_ eq $variety} qw(all sequence choice) )
     {
         # visit child elements
         for (@{ $type->get_element() || [] }) {
@@ -251,7 +246,7 @@ sub visit_XSD_ComplexType {
         return;
     }
 
-    warn "unsupported content model $content_model found in "
+    warn "unsupported content model $variety found in "
         . "complex type " . $type->get_name()
         . " - typemap may be incomplete";
 }
