@@ -8,8 +8,8 @@ our $VERSION=q{2.00_29};
 
 sub start_tag {
     # my ($self, $opt, $value) = @_;
-    return q{} if (@_ < 3); 
-    return qq{ $_[1]->{ name }="}
+    return q{} if (@_ < 3);
+    return qq{ $_[1]->{ name }="};
 }
 
 sub end_tag {
