@@ -7,8 +7,7 @@ our $VERSION=q{2.00_29};
 
 sub serialize {
     # we work on @_ for performance.
-    $_[1] ||= {};                                   # $option_ref
-
+    # $_[1] ||= {};                                   # $option_ref
     return ${ $_[0]->_serialize({ attr => 1 }) };
 }
 
