@@ -9,7 +9,7 @@ require Class::Std::Fast::Storable;
 
 use base qw(SOAP::WSDL::XSD::Typelib::Builtin::anyType);
 
-our $VERSION = '2.00_31';
+our $VERSION = '2.00_33';
 
 my %ELEMENTS_FROM;
 my %ATTRIBUTES_OF;
@@ -44,23 +44,24 @@ my %xml_attr_of :ATTR();
 
 sub attr {
     my $self = shift;
-    my $class = ref $self;
+    my $class = $self->__get_attr_class()
+        or return;
 
     # disable strictness - in perl 5.10 %{ "$foo\::_bar" } triggers a
     # symbolic reference error with strictness enabled
     no strict qw(refs);
-    die "$class has no attributes" if not defined %{ "$class\::_ATTR::"};
+    # die "$class has no attributes" if not defined %{ "$class\::_ATTR::"};
     if (@_) {
         # setter
-        return $xml_attr_of{ $$self } = "$class\::_ATTR"->new(@_);
+        return $xml_attr_of{ $$self } = $class->new(@_);
     }
     return $xml_attr_of{ $$self } if exists $xml_attr_of{ $$self };
-    return $xml_attr_of{ $$self } = "$class\::_ATTR"->new();
+    return $xml_attr_of{ $$self } = $class->new();
 }
 
 sub serialize_attr {
     return q{} if not $xml_attr_of{ ${ $_[0] } };
-    $_[0]->attr()->serialize();
+    return $xml_attr_of{ ${ $_[0] } }->serialize();
 }
 
 sub as_hash_ref {
@@ -118,7 +119,7 @@ sub _factory {
         # it when the method was created.
         my $is_list = $type->isa('SOAP::WSDL::XSD::Typelib::Builtin::list');
 
-        #  The set_$name method below looks rather weird,
+        # The set_$name method below looks rather weird,
         # but is optimized for performance.
         #
         #  We could use sub calls for sure, but these are much slower. And
@@ -173,7 +174,6 @@ sub _factory {
                          ]
                     : $is_ref eq 'HASH'
                         ?  $type->new( $_[1] )
-
                         # neither ARRAY nor HASH - probably an object...
                         :  ($is_ref eq $type)               # of required type ? ->isa would be a better test...
                             ? $_[1]                         # use it
@@ -245,7 +245,7 @@ sub _factory {
     # Triggers XML attribute serialization if the options hash ref contains
     # a attr element with a true value.
     *{ "$class\::_serialize" } = sub {
-        my $ident = ${ $_[0]};
+        my $ident = ${ $_[0] };
         my $option_ref = $_[1];
         # return concatenated return value of serialize call of all
         # elements retrieved from get_elements expanding list refs.
@@ -261,13 +261,13 @@ sub _factory {
                     # serialize element elements with their own serializer
                     # but name them like they're named here.
                     if ( $_->isa( 'SOAP::WSDL::XSD::Typelib::Element' ) ) {
-                            $_->serialize( { name => $name } );
+                            $_->serialize({ name => $name });
                     }
                     # serialize complextype elments (of other types) with their
                     # serializer, but add element tags around.
                     else {
                         join q{}, $_->start_tag({ name => $name , %{ $option_ref } })
-                            , $_->serialize()
+                            , $_->serialize($option_ref)
                             , $_->end_tag({ name => $name , %{ $option_ref } });
                     }
                 } @{ $element }
@@ -277,9 +277,19 @@ sub _factory {
             }
         } (@{ $ELEMENTS_FROM{ $class } });
     };
+
+    # put hidden complex serializer into class
+    # ... but not for AttributeSet classes
+    if ( ! $class->isa('SOAP::WSDL::XSD::Typelib::AttributeSet')) {
+        *{ "$class\::serialize" } = \&__serialize_complex;
+    };
 }
 
-sub serialize {
+# just a fallback
+sub __get_attr_class {};
+
+# hidden complex serializer
+sub __serialize_complex {
     # we work on @_ for performance.
     $_[1] ||= {};                                   # $option_ref
 
@@ -459,9 +469,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 524 $
+ $Rev: 564 $
  $LastChangedBy: kutterma $
- $Id: ComplexType.pm 524 2008-02-10 23:24:43Z kutterma $
+ $Id: ComplexType.pm 564 2008-02-23 13:31:39Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/XSD/Typelib/ComplexType.pm $
 
 =cut
